#########################################################################
# EC2 Builder
# All Rights Reserved.
# Authors:
#   - Fabio Santos B. da Silva
# Version:   0.1.0
# Date:      26/08/2018
# Purpose:   Launch EC2 Instance
#########################################################################

class ec2_builder(
  $key_name,
  $region,
  $cidr_block,
  $vpc_name,
  $availability_zone,
  $igateway_name,
  $routetable_name,
  $subnet_name,
  $sgroup_name,
  $image_id,
  $instance_type,
) {

    ec2_vpc { $vpc_name :
        ensure     => present,
        region     => $region,
        cidr_block => $cidr_block,
        tags       => {
            tag_name => 'value',
        },
    }

    ec2_vpc_internet_gateway { $igateway_name:
        ensure => present,
        region => $region,
        vpc    => $vpc_name,
    }

    ec2_vpc_routetable { $routetable_name:
        ensure => present,
        region => $region,
        vpc    => $vpc_name,
        routes => [
            {
                destination_cidr_block => $cidr_block,
                gateway                => 'local',
            },
            {
                destination_cidr_block => '0.0.0.0/0',
                gateway                => $igateway_name,
            },
        ],
    }

    ec2_vpc_subnet { $subnet_name:
        ensure                  => present,
        region                  => $region,
        cidr_block              => $cidr_block,
        availability_zone       => $availability_zone,
        map_public_ip_on_launch => true,
        vpc                     => $vpc_name,
        route_table             => $routetable_name,
        tags                    => {
            tag_name => 'value',
        },
    }

    ec2_securitygroup { $sgroup_name:
        ensure      => present,
        region      => $region,
        vpc         => $vpc_name,
        description => 'a description of the group',
        ingress     => [{
            protocol => 'tcp',
            port     => 22,
            cidr     => '0.0.0.0/0',
        }],
        tags        => {
            tag_name  => 'value',
        },
    }

    ec2_instance { 'avenuecode_ec2_instance':
        ensure            => running,
        region            => $region,
        availability_zone => $availability_zone,
        image_id          => $image_id, # you need to select your own AMI
        instance_type     => $instance_type,
        key_name          => $key_name,
        subnet            => $subnet_name,
        security_groups   => [$sgroup_name],
        tags              => {
            tag_name => 'value',
        },
    }

}
